@@ -1083,6 +1083,7 @@ static void
 et_build_groups (ETable *et)
 {
 	gboolean was_grouped = et->is_grouped;
+	gboolean alternating_row_colors;
 
 	et->is_grouped = e_table_sort_info_grouping_get_count (et->sort_info) > 0;
 
@@ -1103,9 +1104,19 @@ et_build_groups (ETable *et)
 			E_CANVAS_VBOX (et->canvas_vbox),
 			GNOME_CANVAS_ITEM (et->group));
 
+	alternating_row_colors = et->alternating_row_colors;
+	if (alternating_row_colors) {
+		gboolean bvalue = TRUE;
+
+		/* user can only disable this option, if it's enabled by the specification */
+		gtk_widget_style_get (GTK_WIDGET (et), "alternating-row-colors", &bvalue, NULL);
+
+		alternating_row_colors = bvalue ? 1 : 0;
+	}
+
 	gnome_canvas_item_set (
 		GNOME_CANVAS_ITEM (et->group),
-		"alternating_row_colors", et->alternating_row_colors,
+		"alternating_row_colors", alternating_row_colors,
 		"horizontal_draw_grid", et->horizontal_draw_grid,
 		"vertical_draw_grid", et->vertical_draw_grid,
 		"drawfocus", et->draw_focus,
@@ -3458,6 +3469,15 @@ e_table_class_init (ETableClass *class)
 			G_PARAM_READABLE |
 			G_PARAM_STATIC_STRINGS));
 
+	gtk_widget_class_install_style_property (
+		widget_class,
+		g_param_spec_boolean (
+			"alternating-row-colors",
+			"Alternating Row Colors",
+			"Whether to use alternating row colors",
+			TRUE,
+			G_PARAM_READABLE));
+
 	/* Scrollable interface */
 	g_object_class_override_property (
 		object_class, PROP_HADJUSTMENT, "hadjustment");
@@ -3468,7 +3488,8 @@ e_table_class_init (ETableClass *class)
 	g_object_class_override_property (
 		object_class, PROP_VSCROLL_POLICY, "vscroll-policy");
 
-	gal_a11y_e_table_init ();
+	gtk_widget_class_set_accessible_type (widget_class,
+		GAL_A11Y_TYPE_E_TABLE);
 }
 
 void
