@@ -1522,14 +1522,14 @@ static GtkActionEntry mail_entries[] = {
 	  G_CALLBACK (action_mail_folder_expunge_cb) },
 
 	{ "mail-account-properties",
-	  GTK_STOCK_PROPERTIES,
+	  "document-properties",
 	  N_("_Properties"),
 	  NULL,
 	  N_("Edit properties of this account"),
 	  G_CALLBACK (action_mail_account_properties_cb) },
 
 	{ "mail-account-refresh",
-	  GTK_STOCK_REFRESH,
+	  "view-refresh",
 	  N_("_Refresh"),
 	  NULL,
 	  N_("Refresh list of folders of this account"),
@@ -1557,8 +1557,8 @@ static GtkActionEntry mail_entries[] = {
 	  G_CALLBACK (action_mail_folder_copy_cb) },
 
 	{ "mail-folder-delete",
-	  GTK_STOCK_DELETE,
-	  NULL,
+	  "edit-delete",
+	  N_("_Delete"),
 	  NULL,
 	  N_("Permanently remove this folder"),
 	  G_CALLBACK (action_mail_folder_delete_cb) },
@@ -1592,15 +1592,15 @@ static GtkActionEntry mail_entries[] = {
 	  G_CALLBACK (action_mail_folder_new_cb) },
 
 	{ "mail-folder-properties",
-	  GTK_STOCK_PROPERTIES,
-	  NULL,
+	  "document-properties",
+	  N_("_Properties"),
 	  NULL,
 	  N_("Change the properties of this folder"),
 	  G_CALLBACK (action_mail_folder_properties_cb) },
 
 	{ "mail-folder-refresh",
-	  GTK_STOCK_REFRESH,
-	  NULL,
+	  "view-refresh",
+	  N_("_Refresh"),
 	  "F5",
 	  N_("Refresh the folder"),
 	  G_CALLBACK (action_mail_folder_refresh_cb) },
@@ -1720,7 +1720,7 @@ static GtkActionEntry mail_entries[] = {
 	  G_CALLBACK (action_mail_smart_forward_cb) },
 
 	{ "mail-stop",
-	  GTK_STOCK_STOP,
+	  "process-stop",
 	  N_("Cancel"),
 	  NULL,
 	  N_("Cancel the current mail operation"),
